@@ -15,6 +15,7 @@ package relex.algs;
  * limitations under the License.
  */
 
+import relex.concurrent.RelexContext;
 import relex.feature.FeatureNode;
 
 /**
@@ -29,7 +30,7 @@ public class HeadPlacingAlg extends TemplateMatchingAlg {
 
 	static String allLabelRegex = "(" + subjectLabelRegex + ")|(" + headLabelRegex + ")";
 
-	protected void applyTo(FeatureNode node) {
+	protected void applyTo(FeatureNode node, RelexContext context) {
 	}
 
 }
