@@ -33,6 +33,12 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 
 	private static String RIGHT_LINK_PREFIX = "linkR";
 
+	private static String GENDER_FEATURE_NAME = "GENDER";
+	private static String PERSON_FLAG_NAME = "PERSON-FLAG";
+	private static String MEASURE_FLAG_NAME = "MEASURE-FLAG";
+	private static String LOCATION_FLAG_NAME = "LOCATION-FLAG";
+	private static String ORGANIZATION_FLAG_NAME = "ORGANIZATION-FLAG";
+
 	private static String POS_FEATURE_NAME = "POS";
 
 	private static String WORD_STRING_FEATURE_NAME = "str";
@@ -200,17 +206,56 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 		ths.set(s, link);
 	}
 
+	private static void setFeat(FeatureNode ths, String featname, String featval)
+	{
+		throwIfNoFN(ths);
+		FeatureNode f = ths.get(featname);
+		if (f != null)
+			f.setValue(featval);
+		else
+			ths.set(featname, new FeatureNode(featval));
+	}
+
+	public static void setLocation(FeatureNode ths)
+	{
+		setFeat(ths, LOCATION_FLAG_NAME, "T");
+	}
+
+	public static void setMeasure(FeatureNode ths)
+	{
+		setFeat(ths, MEASURE_FLAG_NAME, "T");
+	}
+
+	public static void setOrganization(FeatureNode ths)
+	{
+		setFeat(ths, ORGANIZATION_FLAG_NAME, "T");
+	}
+
+	public void setPerson() {
+		setPerson(fn());
+	}
+
+	public static void setPerson(FeatureNode ths)
+	{
+		setFeat(ths, PERSON_FLAG_NAME, "T");
+	}
+
+	public void setGender(String gen) {
+		setGender(fn(), gen);
+	}
+
+	public static void setGender(FeatureNode ths, String gen)
+	{
+		setFeat(ths, GENDER_FEATURE_NAME, gen);
+	}
+
 	public void setPOS(String pos) {
 		setPOS(fn(), pos);
 	}
 
-	public static void setPOS(FeatureNode ths, String pos) {
-		throwIfNoFN(ths);
-		FeatureNode f = ths.get(POS_FEATURE_NAME);
-		if (f != null)
-			f.setValue(pos);
-		else
-			ths.set(POS_FEATURE_NAME, new FeatureNode(pos));
+	public static void setPOS(FeatureNode ths, String pos)
+	{
+		setFeat(ths, POS_FEATURE_NAME, pos);
 	}
 
 	public String getPOS() {
@@ -229,9 +274,62 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 		setWordAndPos(fn(), wordString);
 	}
 
-	public static void setWordAndPos(FeatureNode ths, String wordString) {
+	/**
+	 * This method is expecting an "inflected" link-grammar
+	 * word, such as "knows.v" or "ball.n", indicating that
+	 * the word was a verb, noun, etc.
+	 */
+	public static void setWordAndPos(FeatureNode ths, String wordString)
+	{
 		throwIfNoFN(ths);
-		setPOS(ths, POS_WORD);
+
+		int len = wordString.length();
+		if ((2 < len) && (wordString.indexOf('.') == len -2))
+		{
+			char inflection = wordString.charAt(len-1);
+			wordString = wordString.substring(0, len-2);
+			switch(inflection)
+			{
+				case 'a': setPOS(ths, "adj"); break;
+				case 'b': setPOS(ths, "noun"); break; // male or female
+				case 'e': setPOS(ths, "adv"); break; // adverbs alternate
+				case 'f': setPOS(ths, "noun"); break; // female
+				case 'g': setPOS(ths, "verb"); break; // gerund
+				case 'l': setPOS(ths, "noun"); break; // location
+				case 'm': setPOS(ths, "noun"); break; // male
+				case 'n': setPOS(ths, "noun"); break;
+				case 'o': setPOS(ths, "noun"); break; // organizations
+				case 'p': setPOS(ths, "noun"); break; // plural (mass) nouns
+				case 's': setPOS(ths, "noun"); break; // singular, mass or count nouns
+				case 't':  // titles, roles
+				case 'u': setPOS(ths, "noun"); break; // units of measurement
+				case 'v': setPOS(ths, "verb"); break;
+				case 'w': setPOS(ths, "verb"); break; // verb, exceptions
+				case 'x': setPOS(ths, "abbr"); break; // prefix abbreviation e.g. Mr.
+				case 'y': setPOS(ths, "abbr"); break; // postfix abbreviation e.g. Ave.
+				case 'c':  // ??
+				case 'd':  // ??
+				case 'i':  // ??
+				case 'k':  // ??
+				case 'q':  // question-related ??
+				case 'r':  // preposition-like things
+				default: setPOS(ths, POS_WORD); break;
+			}
+			switch(inflection)
+			{
+				case 'b':  setPerson(ths); break; // male or female
+				case 'f':  setPerson(ths); setGender(ths, "feminine"); break;
+				case 'l':  setLocation(ths); break;
+				case 'm':  setPerson(ths); setGender(ths, "masculine"); break;
+				case 'o':  setOrganization(ths); break;
+				case 't':  // titles, roles
+				case 'u':  setMeasure(ths); break; // u == unit
+			}
+		}
+		else
+		{
+			setPOS(ths, POS_WORD);
+		}
 		ths.set(WORD_STRING_FEATURE_NAME, new FeatureNode(wordString));
 	}
 
