@@ -109,7 +109,7 @@ public class LinkParser extends Parser
 			// SKIPPED=" + cNumSkippedWords());
 			for (int w = 0; w < numWords; w++)
 			{
-				String wordString = lpc.getWord(w);
+				String wordString = lpc.getLinkageWord(w);
 				if (verbosity >= 5) System.out.println(" Processing Word " + wordString);
 
 				if (wordString.equals("RIGHT-WALL")){
@@ -121,7 +121,7 @@ public class LinkParser extends Parser
 					if (leftWall == null) throw new RuntimeException("Invalid parse: first word is not left wall");
 					
 					// set the word and part-of-speach
-					fnv.setWordAndPos(lpc.getWord(w));
+					fnv.setWordAndPos(wordString);
 					
 					// create a feature "this" which points to the linkable
 					fnv.fn().set("this", fnv.fn());
